Index: src/dateparser.h |
diff --git a/src/dateparser.h b/src/dateparser.h |
index f284590264175bc4a7a79bb87873d89ad3c2d502..15a971a8cca411e7bd97ec35e67323b6602cdc6e 100644 |
--- a/src/dateparser.h |
+++ b/src/dateparser.h |
@@ -367,13 +367,13 @@ class DateParser : public AllStatic { |
bool is_iso_date_; |
}; |
// Tries to parse an ES5 Date Time String. Returns the next token |
// to continue with in the legacy date string parser. If parsing is |
// complete, returns DateToken::EndOfInput(). If terminally unsuccessful, |
// returns DateToken::Invalid(). Otherwise parsing continues in the |
// legacy parser. |
template <typename Char> |
- static DateParser::DateToken ParseES5DateTime( |
+ static DateParser::DateToken ParseES6DateTime( |
DateStringTokenizer<Char>* scanner, |
DayComposer* day, |
TimeComposer* time, |
@@ -367,13 +367,13 @@ class DateParser : public AllStatic { |
bool is_iso_date_; |
}; |
- // Tries to parse an ES5 Date Time String. Returns the next token |
+ // Tries to parse an ES6 Date Time String. Returns the next token |
// to continue with in the legacy date string parser. If parsing is |
// complete, returns DateToken::EndOfInput(). If terminally unsuccessful, |